<template>
  <a-card :bordered="false">

    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form layout="inline" @keyup.enter.native="searchQuery">
        <a-row :gutter="24">
          <a-col :xl="6" :lg="7" :md="8" :sm="24">
            <a-form-item label="工单编号">
              <a-input placeholder="请输入工单编号" v-model="queryParam.repairCode"></a-input>
            </a-form-item>
          </a-col>
          <template v-if="toggleSearchStatus">
            <a-col :xl="6" :lg="7" :md="8" :sm="24">
              <a-form-item label="设备编号">
                <lx-search-equipment-select placeholder="请输入设备编号或名称搜索" v-model="queryParam.equipmentId"/>
              </a-form-item>
            </a-col>
            <a-col :xl="6" :lg="7" :md="8" :sm="24">
              <a-form-item label="维修状态">
                <a-input placeholder="请输入维修状态" v-model="queryParam.repairStatus"></a-input>
              </a-form-item>
            </a-col>
          </template>
          <a-col :xl="6" :lg="7" :md="8" :sm="24">
            <span style="float: left;overflow: hidden;" class="table-page-search-submitButtons">
              <a-button type="primary" @click="searchQuery" icon="search">查询</a-button>
              <a-button @click="searchReset" icon="reload" style="margin-left: 8px">重置</a-button>
              <a @click="handleToggleSearch" style="margin-left: 8px">
                {{ toggleSearchStatus ? '收起' : '展开' }}
                <a-icon :type="toggleSearchStatus ? 'up' : 'down'"/>
              </a>
            </span>
          </a-col>

        </a-row>
      </a-form>
    </div>

    <!-- 操作按钮区域 -->
    <div class="table-operator">
      <a-button @click="handleAdd" type="primary" icon="plus">新增</a-button>
      <a-button type="primary" icon="download" @click="handleExportXls('维修工单')">导出</a-button>
      <a-dropdown v-if="selectedRowKeys.length > 0">
        <a-menu slot="overlay">
          <a-menu-item key="1" @click="batchDel">
            <a-icon type="delete"/>
            删除
          </a-menu-item>
        </a-menu>
        <a-button style="margin-left: 8px"> 批量操作
          <a-icon type="down"/>
        </a-button>
      </a-dropdown>
    </div>

    <!-- table区域-begin -->
    <div>
      <div class="ant-alert ant-alert-info" style="margin-bottom: 16px;">
        <i class="anticon anticon-info-circle ant-alert-icon"></i> 已选择 <a
        style="font-weight: 600">{{ selectedRowKeys.length }}</a>项
        <a style="margin-left: 24px" @click="onClearSelected">清空</a>
      </div>

      <a-table
        ref="table"
        size="middle"
        bordered
        rowKey="id"
        :columns="columns"
        :dataSource="dataSource"
        :pagination="ipagination"
        :loading="loading"
        class="j-table-force-nowrap"
        :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}"
        @change="handleTableChange"
        :scroll="{x:'max-content'}"
      >

        <span slot="action" slot-scope="text, record">
          <a @click="handleEdit(record)">编辑</a>

          <a-divider type="vertical"/>
          <a-dropdown>
            <a class="ant-dropdown-link">更多 <a-icon type="down"/></a>
            <a-menu slot="overlay">
              <a-menu-item>
                <a-popconfirm title="确定删除吗?" @confirm="() => handleDelete(record.id)">
                  <a>删除</a>
                </a-popconfirm>
              </a-menu-item>
            </a-menu>
          </a-dropdown>
        </span>

      </a-table>
    </div>
    <!-- table区域-end -->

    <!-- 表单区域 -->
    <eamRepairOrder-modal ref="modalForm" @ok="modalFormOk"></eamRepairOrder-modal>
  </a-card>
</template>

<script>
import '@/assets/less/TableExpand.less'
import EamRepairOrderModal from './modules/EamRepairOrderModal'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import LxSearchEquipmentSelect from '@views/eam/equipment/modules/LxSearchEquipmentSelect.vue'

export default {
  name: 'EamRepairOrderList',
  mixins: [JeecgListMixin],
  components: {
    LxSearchEquipmentSelect,
    EamRepairOrderModal
  },
  data() {
    return {
      description: '维修工单管理页面',
      // 表头
      columns: [
        {
          title: '工单编号',
          align: 'center',
          dataIndex: 'repairCode',
          width: 200,
          fixed: 'left'
        },
        // {
        //   title: '报修编号',
        //   align: 'center',
        //   dataIndex: 'reportId',
        //   width: 200,
        //   fixed: 'left'
        // },
        {
          title: '设备编号',
          align: 'center',
          dataIndex: 'equipmentId_dictText',
          width: 200,
          fixed: 'left'
        },
        {
          title: '状态',
          align: 'center',
          dataIndex: 'repairStatus_dictText',
          fixed: 'left',
          width: 100
        },
        {
          title: '维修开始时间',
          align: 'center',
          dataIndex: 'actualStartTime',
          width: 200
        },
        {
          title: '维修结束时间',
          align: 'center',
          dataIndex: 'actualEndTime',
          width: 200
        },
        {
          title: '故障原因',
          align: 'center',
          dataIndex: 'faultReason'
        },
        {
          title: '维修结果描述',
          align: 'center',
          dataIndex: 'repairDescription',
          width: 300
        },
        {
          title: '维修负责人',
          align: 'center',
          dataIndex: 'repairer',
          width: 100
        },
        // {
        //   title: '是否委外',
        //   align: 'center',
        //   dataIndex: 'outsourcedFlag',
        //   width: 100
        // },
        // {
        //   title: '委外维修描述',
        //   align: 'center',
        //   dataIndex: 'outsourcedRepairDecription',
        //   width: 300
        // },
        // {
        //   title: '委外维修开始时间',
        //   align: 'center',
        //   dataIndex: 'outsourcedStartTime',
        //   width: 200
        // },
        // {
        //   title: '委外维修结束时间',
        //   align: 'center',
        //   dataIndex: 'outsourcedEndTime',
        //   width: 200
        // },
        // {
        //   title: '委外负责人',
        //   align: 'center',
        //   dataIndex: 'outsourcedPerson',
        //   width: 100
        // },
        {
          title: '维修图片',
          align: 'center',
          dataIndex: 'imageFiles',
          width: 100
        },
        {
          title: '操作',
          dataIndex: 'action',
          align: 'center',
          scopedSlots: { customRender: 'action' },
          fixed: 'right',
          width: 150
        }
      ],
      url: {
        list: '/eam/eamRepairOrder/list',
        delete: '/eam/eamRepairOrder/delete',
        deleteBatch: '/eam/eamRepairOrder/deleteBatch',
        exportXlsUrl: 'eam/eamRepairOrder/exportXls',
      }
    }
  },
  computed: {
    importExcelUrl: function() {
      return `${window._CONFIG['domianURL']}/${this.url.importExcelUrl}`
    }
  },
  methods: {}
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>